@@ -30,6 +30,13 @@ class gerstlixAPI():
         else:
             return {"status": "fail", "message":"Укажите параметры!"}
 
+    def get_info(self, server:int=None):
+        if server in acceptServers and server != None:
+            r = requests.get(f"https://api2.gerstlix.com/v1/server.getInfo/?token={self.token}&server={server}")
+            return r.json()
+        else:
+            return f"Сервер: {server} не находится в одобренном списке"
+
         
     def get_status(self, gameProject:str=None):
         if gameProject in acceptProject:
